PCB Environment: Track Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions
Track Class Reference

## Public Member Functions
| Track (const Point_25 &start)
const Point_25 & | start () const
const Point_25 & | end () const
bool | empty () const
const WideSegment_25 & | getSegment (uint i) const
const std::vector< WideSegment_25 > & | getSegments () const
uint | numSegments () const
bool | hasSegments () const
void | setSegments (const std::vector< Segment_25 > &)
void | setSegments (const std::vector< WideSegment_25 > &)
void | setSegments (std::vector< WideSegment_25 > &&)
const Via & | getVia (uint i) const
const std::vector< Via > & | getVias () const
uint | numVias () const
bool | hasVias () const
bool | startsWithVia () const
bool | endsWithVia () const
bool | inferStartsWithVia () const
bool | inferEndsWithVia () const
ContactType | canAttach (const Track &) const
bool | touchesEndToStart (const Track &) const
bool | touchesEndToEnd (const Track &) const
bool | touchesStartToStart (const Track &) const
bool | touchesStartToEnd (const Track &) const
void | setStart (const Point_25 &)
void | setEnd (const Point_25 &)
void | _setEnd (const Point_25 &v)
void | moveStartTo (const Point_25 &)
void | moveEndTo (const Point_25 &)
void | _setEndLayer (uint)
void | _setEndLayer (const Point_25 &)
void | inferStart ()
void | inferEnd ()
void | inferEndpoints ()
void | setPath (const Path &, bool updateStart=false)
void | _setPath (const Path &)
void | getPath (Path &) const
void | setVias (const std::vector< Via > &vias)
void | setVias (std::vector< Via > &&vias)
void | autocreateVias (const Point_25 &end)
void | setModified ()
void | append (const Track &)
void | appendMove (Track *)
void | append (const WideSegment_25 &)
void | appendSegment (const Point_25 &, const Point_25 &)
void | append (const Via &)
void | appendVia (const Point_2 &, uint z0, uint z1, Real r=std::numeric_limits< Real >::quiet_NaN())
void | prepend (const Via &)
Via | popVia ()
WideSegment_25 | popSegment ()
void | popSafe ()
void | _append (const WideSegment_25 &)
void | _append (const Segment_25 &)
void | _appendVia (const Point_2 &, uint z0, uint z1, Real r)
void | extendTo (const Point_25 &, uint viaLocation)
void | _extendTo (const Point_25 &)
void | extendToLayer (uint z)
bool | isContiguous () const
bool | hasValidEnds () const
void | clear ()
Real | reduceBy_cells (Real len_cells, const Real len_perLayer, const Real tolerance)
Real | reduceSegmentsBy_cells (Real len_cells, const Real tolerance)
Real | reduceViaBy_cells (Real len_cells, const Real len_perLayer, const Real tolerance)
void | reverse ()
Real | defaultWidth () const
Real | defaultViaDiameter () const
Real | defaultViaRadius () const
void | setDefaultWidth (float w)
void | setDefaultViaDiameter (Real d)
Real | length () const
void | computeLength ()
void | setSegmentCapsMask (uint8_t m)
bool | hasStartCap () const
bool | hasEndCap () const
bool | hasSegmentJoints () const
Bbox_2 | bbox (Real clearance, int z=-1) const
| @z < 0 means all layers.
bool | snapToStart (Point_25 &, const Point_25 &, Real maxDistance=0.0) const
bool | snapToEnd (Point_25 &, const Point_25 &, Real maxDistance=0.0) const
int | snapToEndpoint (Point_25 &, const Point_25 &, Real maxDistance=0.0) const
void | determineForks (std::vector< uint > &indices, const Connection &)
Real | shortcutBetween (uint sourcePos, uint targetPos)
bool | violatesClearance (const Pin &, Real clearance, Point_25 *=0) const
| Check whether the other item comes within @clearance distance of this one.
bool | violatesClearance (const Track &, Real clearance, Point_25 *=0) const
bool | violatesClearance2D (const Track &, Real clearance, Point_25 *=0) const
bool | violatesClearance (const Via &, Real clearance, Point_25 *=0) const
bool | violatesClearance (const WideSegment_25 &, Real clearance, Point_25 *=0) const
bool | intersects (const Bbox_2 &, uint zmin, uint zmax) const
bool | isRasterized () const
void | resetRasterizedCount ()
void | addRasterizedCount (int count) const
bool | checkRasterization (const NavGrid &) const
bool | updateForRemovedLayers (uint zmin, uint zmax)
std::string | str () const
void | setPy (PyObject *)
PyObject * | getViasPy () const
PyObject * | getViasNumpy () const
PyObject * | getSegmentsPy () const
PyObject * | getSegmentsNumpy () const
PyObject * | getPathPy () const
PyObject * | getPathNumpy () const
PyObject * | getPy (bool asNumpy) const

## Static Public Member Functions
static void | _reverseSegments (std::vector< WideSegment_25 > &)

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Track.hpp